MarkerExt

Trait MarkerExt 

pub trait MarkerExt: IsA<Marker> + 'static {
Show 21 methods // Provided methods fn animate_in(&self) { ... } fn animate_in_with_delay(&self, delay: u32) { ... } fn animate_out(&self) { ... } fn animate_out_with_delay(&self, delay: u32) { ... } fn child(&self) -> Option<Widget> { ... } fn is_draggable(&self) -> bool { ... } fn hotspot(&self) -> (f64, f64) { ... } fn is_selectable(&self) -> bool { ... } fn is_selected(&self) -> bool { ... } fn set_child(&self, child: Option<&impl IsA<Widget>>) { ... } fn set_draggable(&self, value: bool) { ... } fn set_hotspot(&self, x_hotspot: f64, y_hotspot: f64) { ... } fn set_selectable(&self, value: bool) { ... } fn x_hotspot(&self) -> f64 { ... } fn set_x_hotspot(&self, x_hotspot: f64) { ... } fn y_hotspot(&self) -> f64 { ... } fn set_y_hotspot(&self, y_hotspot: f64) { ... } fn connect_child_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_selectable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_x_hotspot_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... } fn connect_y_hotspot_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId { ... }
}
Trait containing all Marker methods.

Implementors

Marker, Point

Provided Methods

fn animate_in(&self)

fn animate_in_with_delay(&self, delay: u32)

fn animate_out(&self)

fn animate_out_with_delay(&self, delay: u32)

fn child(&self) -> Option<Widget>

Retrieves the current child of @self.

Returns

a #GtkWidget.

fn is_draggable(&self) -> bool

fn hotspot(&self) -> (f64, f64)

Get the hotspot point for the given marker. The value is in pixel relative to the top-left corner. Any negative value means that the hotspot get computed with the halign or valign properties.

Returns
x_hotspot

return value for the x hotspot

y_hotspot

return value for the y hotspot

fn is_selectable(&self) -> bool

Checks whether the marker is selectable.

Returns

the selectable or not state of the marker.

fn is_selected(&self) -> bool

Checks whether the marker is selected.

Returns

true if the marker is selected, otherwise false

fn set_child(&self, child: Option<&impl IsA<Widget>>)

Sets the child widget of @self.

child

a #GtkWidget

fn set_draggable(&self, value: bool)

fn set_hotspot(&self, x_hotspot: f64, y_hotspot: f64)

Set the hotspot point for the given marker. The value is in pixel relative to the top-left corner. Use any negative value to fallback to the halign or valign properties.

x_hotspot

the x hotspot

y_hotspot

the y hotspot

fn set_selectable(&self, value: bool)

Sets the marker as selectable or not.

value

the selectable state

fn x_hotspot(&self) -> f64

The x hotspot of the marker, a negative value means that the actual x hotspot is calculated with the halign property. The x hotspot should not be more than the width of the widget.

fn set_x_hotspot(&self, x_hotspot: f64)

The x hotspot of the marker, a negative value means that the actual x hotspot is calculated with the halign property. The x hotspot should not be more than the width of the widget.

fn y_hotspot(&self) -> f64

The y hotspot of the marker, a negative value means that the actual y hotspot is calculated with the valign property. The y hotspot should not be more than the height of the widget.

fn set_y_hotspot(&self, y_hotspot: f64)

The y hotspot of the marker, a negative value means that the actual y hotspot is calculated with the valign property. The y hotspot should not be more than the height of the widget.

fn connect_child_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

fn connect_selectable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_x_hotspot_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

fn connect_y_hotspot_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors

Source

impl<O: IsA<Marker>> MarkerExt for O