pub struct DataSource { /* private fields */ }Expand description
The base class used to retrieve tiles as [glib::Bytes][crate::glib::Bytes].
This is an Abstract Base Class, you cannot instantiate it.
Properties
max-zoom-level
The maximum zoom level
Readable | Writable | Construct
min-zoom-level
The minimum zoom level
Readable | Writable | Construct
Signals
received-data
Emitted when data is received for any tile. This includes any intermediate steps, such as data from the file cache, as well as the final result.
Implements
DataSourceExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl DataSource
impl DataSource
pub const NONE: Option<&'static DataSource> = None