pub struct DataSourceRequest { /* private fields */ }Expand description
Represents a request to a DataSource for a tile.
Data sources can return a tile multiple times. For example, a
TileDownloader may return cached data first, then later return data
from a network service when it arrives. This allows the map to be rendered
as quickly as possible without waiting for the network unnecessarily.
Conventional async/finish method pairs don’t support multiple returns.
Instead, DataSourceExt::start_request() is available, which returns a
DataSourceRequest whose properties, data
and error, update as data becomes available.
The [notify][struct@crate::glib::Object#notify] signal can be used to watch for these
changes. When the request is done and no more data will be returned,
completed is set to true.
DataSource implementations can use a subclass of
DataSourceRequest, but the base class should be sufficient in most
cases.
Properties
completed
true if the request has been completed, otherwise false. A completed
request will not receive further updates to either
data or error.
Readable
data
The most recent data for the tile, if available. If an error is emitted,
this will be set to None.
Readable
error
The error that occurred during the request, if any.
Readable
x
The X coordinate of the requested tile.
Readable | Writable | Construct Only
y
The Y coordinate of the requested tile.
Readable | Writable | Construct Only
zoom-level
The zoom level of the requested tile.
Readable | Writable | Construct Only
Implements
DataSourceRequestExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl DataSourceRequest
impl DataSourceRequest
pub const NONE: Option<&'static DataSourceRequest> = None
Sourcepub fn new(x: i32, y: i32, zoom_level: i32) -> DataSourceRequest
pub fn new(x: i32, y: i32, zoom_level: i32) -> DataSourceRequest
Creates a new DataSourceRequest.
Only implementations of DataSourceImpl::start_request() should need to
construct a new request object.
x
X coordinate of the requested tile
y
Y coordinate of the requested tile
zoom_level
Zoom level of the requested tile
Returns
a new DataSourceRequest
Sourcepub fn builder() -> DataSourceRequestBuilder
pub fn builder() -> DataSourceRequestBuilder
Creates a new builder-pattern struct instance to construct DataSourceRequest objects.
This method returns an instance of DataSourceRequestBuilder which can be used to create DataSourceRequest objects.