pub struct MapSource { /* private fields */ }Expand description
The base class for all map sources. Map sources fill Tile objects
with images from various sources: a web API, for example, or a test pattern
generated on demand.
The most common map source is RasterRenderer, which fetches tiles
using a TileDownloader.
This is an Abstract Base Class, you cannot instantiate it.
Properties
id
The id of the map source
Readable | Writable | Construct
license
The usage license of the map source
Readable | Writable | Construct
license-uri
The usage license’s uri for more information
Readable | Writable | Construct
max-zoom-level
The maximum zoom level
Readable | Writable | Construct
min-zoom-level
The minimum zoom level
Readable | Writable | Construct
name
The name of the map source
Readable | Writable | Construct
projection
The map projection of the map source
Readable | Writable | Construct
tile-size
The tile size of the map source
Readable | Writable | Construct
Signals
modified
Emitted when the source is modified in such a way that tiles previously filled by it should be refreshed.
It is the MapSource implementation’s responsibility to emit this signal when appropriate, such as when a
data source or rendering parameter changes.
Implements
MapSourceExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations