Point

Struct Point 

pub struct Point { /* private fields */ }
A simple variant of Marker showing the location of the point as a circle on the map.

CSS nodes

ShumatePoint has a single CSS node with the name “map-point”.

Implements

MarkerExt, gtk::prelude::WidgetExt, [trait@glib::ObjectExt], gtk::prelude::AccessibleExt, gtk::prelude::BuildableExt, gtk::prelude::ConstraintTargetExt, LocationExt

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl Point

pub fn new() -> Point

Creates an instance of #ShumatePoint.

Returns

a new #ShumatePoint.

pub fn builder() -> PointBuilder

Creates a new builder-pattern struct instance to construct Point objects.

This method returns an instance of PointBuilder which can be used to create Point objects.