pub struct RasterRenderer { /* private fields */ }Expand description
Properties
data-source
The data source that provides image tiles to display. In most cases,
a TileDownloader is sufficient.
Readable | Writable | Construct Only
MapSource
id
The id of the map source
Readable | Writable | Construct
license
The usage license of the map source
Readable | Writable | Construct
license-uri
The usage license’s uri for more information
Readable | Writable | Construct
max-zoom-level
The maximum zoom level
Readable | Writable | Construct
min-zoom-level
The minimum zoom level
Readable | Writable | Construct
name
The name of the map source
Readable | Writable | Construct
projection
The map projection of the map source
Readable | Writable | Construct
tile-size
The tile size of the map source
Readable | Writable | Construct
Implements
MapSourceExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl RasterRenderer
impl RasterRenderer
Sourcepub fn new(data_source: &impl IsA<DataSource>) -> RasterRenderer
pub fn new(data_source: &impl IsA<DataSource>) -> RasterRenderer
Creates a new RasterRenderer that uses the given data source.
data_source
a DataSource to provide tile image data
Returns
a newly constructed RasterRenderer
Sourcepub fn from_url(url_template: &str) -> RasterRenderer
pub fn from_url(url_template: &str) -> RasterRenderer
Creates a new RasterRenderer that fetches tiles from the given URL
using a TileDownloader data source.
Equivalent to:
⚠️ The following code is in c ⚠️
g_autoptr(ShumateTileDownloader) source = shumate_tile_downloader_new (url_template);
ShumateRasterRenderer *renderer = shumate_raster_renderer_new (source);url_template
a URL template to fetch tiles from
Returns
a newly constructed RasterRenderer
Sourcepub fn new_full(
id: &str,
name: &str,
license: &str,
license_uri: &str,
min_zoom: u32,
max_zoom: u32,
tile_size: u32,
projection: MapProjection,
data_source: &impl IsA<DataSource>,
) -> RasterRenderer
pub fn new_full( id: &str, name: &str, license: &str, license_uri: &str, min_zoom: u32, max_zoom: u32, tile_size: u32, projection: MapProjection, data_source: &impl IsA<DataSource>, ) -> RasterRenderer
Creates a new RasterRenderer with the given details and a data
source.
id
the map source’s id
name
the map source’s name
license
the map source’s license
license_uri
the map source’s license URI
min_zoom
the map source’s minimum zoom level
max_zoom
the map source’s maximum zoom level
tile_size
the map source’s tile size (in pixels)
projection
the map source’s projection
data_source
a DataSource to provide tile image data
Returns
a newly constructed RasterRenderer
Sourcepub fn new_full_from_url(
id: &str,
name: &str,
license: &str,
license_uri: &str,
min_zoom: u32,
max_zoom: u32,
tile_size: u32,
projection: MapProjection,
url_template: &str,
) -> RasterRenderer
pub fn new_full_from_url( id: &str, name: &str, license: &str, license_uri: &str, min_zoom: u32, max_zoom: u32, tile_size: u32, projection: MapProjection, url_template: &str, ) -> RasterRenderer
Creates a new RasterRenderer with the given details and a data
source.
id
the map source’s id
name
the map source’s name
license
the map source’s license
license_uri
the map source’s license URI
min_zoom
the map source’s minimum zoom level
max_zoom
the map source’s maximum zoom level
tile_size
the map source’s tile size (in pixels)
projection
the map source’s projection
url_template
a URL template to fetch tiles from
Returns
a newly constructed RasterRenderer
Sourcepub fn builder() -> RasterRendererBuilder
pub fn builder() -> RasterRendererBuilder
Creates a new builder-pattern struct instance to construct RasterRenderer objects.
This method returns an instance of RasterRendererBuilder which can be used to create RasterRenderer objects.
Sourcepub fn data_source(&self) -> Option<DataSource>
pub fn data_source(&self) -> Option<DataSource>
The data source that provides image tiles to display. In most cases,
a TileDownloader is sufficient.