Tile

Struct Tile 

pub struct Tile { /* private fields */ }
An object that represents map tiles. Tiles are loaded by a MapSource.

Properties

fade-in

Specifies whether the tile should fade in when loading

Readable | Writable

paintable

The [gdk::Paintable][crate::gdk::Paintable] backing the tile

Readable | Writable

scale-factor

The scale factor of the widget the tile will be displayed in.

Readable | Writable

size

The size of the tile in pixels

Readable | Writable

state

The state of the tile

Readable | Writable

x

The x position of the tile

Readable | Writable

y

The y position of the tile

Readable | Writable

zoom-level

The zoom level of the tile

Readable | Writable

Implements

[trait@glib::ObjectExt]

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl Tile

pub fn new() -> Tile

Creates an instance of #ShumateTile.

Returns

a new #ShumateTile

pub fn new_full(x: u32, y: u32, size: u32, zoom_level: u32) -> Tile

Creates an instance of #ShumateTile.

x

the x position

y

the y position

size

the size in pixels

zoom_level

the zoom level

Returns

a #ShumateTile

pub fn builder() -> TileBuilder

Creates a new builder-pattern struct instance to construct Tile objects.

This method returns an instance of TileBuilder which can be used to create Tile objects.

pub fn is_fade_in(&self) -> bool

Checks whether the tile should fade in.

Returns

the return value determines whether the tile should fade in when loading.

pub fn paintable(&self) -> Option<Paintable>

Get the [gdk::Paintable][crate::gdk::Paintable] representing this tile.

Returns

A [gdk::Paintable][crate::gdk::Paintable]

pub fn scale_factor(&self) -> f64

Gets the scale factor of the tile.

Returns

the scale factor

pub fn size(&self) -> u32

Gets the tile’s size.

Returns

the tile’s size in pixels

pub fn state(&self) -> State

Gets the current state of tile loading.

Returns

the tile’s #ShumateState

pub fn x(&self) -> u32

Gets the tile’s x position.

Returns

the tile’s x position

pub fn y(&self) -> u32

Gets the tile’s y position.

Returns

the tile’s y position

pub fn zoom_level(&self) -> u32

Gets the tile’s zoom level.

Returns

the tile’s zoom level

pub fn set_fade_in(&self, fade_in: bool)

Sets the flag determining whether the tile should fade in when loading

fade_in

determines whether the tile should fade in when loading

pub fn set_paintable(&self, paintable: &impl IsA<Paintable>)

Sets the [gdk::Paintable][crate::gdk::Paintable] representing this tile.

paintable

a [gdk::Paintable][crate::gdk::Paintable]

pub fn set_scale_factor(&self, scale_factor: f64)

Sets the scale factor of the tile.

scale_factor

the scale factor

pub fn set_size(&self, size: u32)

Sets the tile’s size

size

the size in pixels

pub fn set_state(&self, state: State)

Sets the tile’s #ShumateState

state

a #ShumateState

pub fn set_x(&self, x: u32)

Sets the tile’s x position

x

the position

pub fn set_y(&self, y: u32)

Sets the tile’s y position

y

the position

pub fn set_zoom_level(&self, zoom_level: u32)

Sets the tile’s zoom level

zoom_level

the zoom level

pub fn connect_fade_in_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_paintable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_scale_factor_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_size_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId

pub fn connect_x_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

pub fn connect_y_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId

pub fn connect_zoom_level_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId