pub struct TileDownloader { /* private fields */ }Expand description
A DataSource that asynchronously downloads tiles from an online
service using a given template.
It contains an internal FileCache to cache the tiles on the system.
Properties
url-template
A template for construting the URL to download a tile from.
The template has the following replacements:
- “{x}”: The X coordinate of the tile
- “{y}”: The Y coordinate of the tile
- “{z}”: The zoom level of the tile
- “{tmsy}”: The inverted Y coordinate (i.e. tile numbering starts with 0 at the bottom, rather than top, of the map)
Readable | Writable | Construct Only
DataSource
max-zoom-level
The maximum zoom level
Readable | Writable | Construct
min-zoom-level
The minimum zoom level
Readable | Writable | Construct
Implements
DataSourceExt, [trait@glib::ObjectExt]
GLib type: GObject with reference counted clone semantics.
Implementations
Sourceimpl TileDownloader
impl TileDownloader
Sourcepub fn new(url_template: &str) -> TileDownloader
pub fn new(url_template: &str) -> TileDownloader
Creates a new TileDownloader that fetches tiles from an API and
caches them on disk.
See url-template for the format of the URL template.
url_template
a URL template to fetch tiles from
Returns
a newly constructed TileDownloader
Sourcepub fn url_template(&self) -> Option<GString>
pub fn url_template(&self) -> Option<GString>
A template for construting the URL to download a tile from.
The template has the following replacements:
- “{x}”: The X coordinate of the tile
- “{y}”: The Y coordinate of the tile
- “{z}”: The zoom level of the tile
- “{tmsy}”: The inverted Y coordinate (i.e. tile numbering starts with 0 at the bottom, rather than top, of the map)