VectorSprite

Struct VectorSprite 

pub struct VectorSprite { /* private fields */ }
A sprite used to draw textures or icons.

Symbolic icons

If a sprite is created from a gtk::SymbolicPaintable source, such as a symbolic icon, then when the sprite is part of a symbol layer it will be drawn using the icon-color property (or the text color, if the sprite is part of a formatted string).

Properties

height

The height at which the sprite should be drawn, in pixels.

Readable | Writable | Construct Only

scale-factor

The intended scale factor of the sprite.

Readable | Writable | Construct Only

source-paintable

The [gdk::Paintable][crate::gdk::Paintable] used to draw the sprite.

Readable | Writable | Construct Only

source-rect

The area of the source rectangle to draw, or None to use the entire paintable.

Readable | Writable | Construct Only

width

The width at which the sprite should be drawn, in pixels.

Readable | Writable | Construct Only

Implements

[trait@glib::ObjectExt], gdk::prelude::PaintableExt, gtk::prelude::SymbolicPaintableExt

GLib type: GObject with reference counted clone semantics.

Implementations

Source

impl VectorSprite

pub fn new(source_paintable: &impl IsA<Paintable>) -> VectorSprite

Creates a new VectorSprite using the paintable’s intrinsic size.

source_paintable

a [gdk::Paintable][crate::gdk::Paintable]

pub fn new_full( source_paintable: &impl IsA<Paintable>, width: i32, height: i32, scale_factor: f64, source_rect: Option<&Rectangle>, ) -> VectorSprite

Creates a new VectorSprite with the given size, scale factor, and area of the source paintable.

source_paintable

a [gdk::Paintable][crate::gdk::Paintable]

width

the width of the sprite in pixels

height

the height of the sprite in pixels

scale_factor

the intended scale factor of the sprite

source_rect

the source rectangle of the sprite, or None to use the entire paintable

pub fn builder() -> VectorSpriteBuilder

Creates a new builder-pattern struct instance to construct VectorSprite objects.

This method returns an instance of VectorSpriteBuilder which can be used to create VectorSprite objects.

pub fn height(&self) -> i32

Gets the height at which the sprite should be drawn.

Returns

the sprite’s height in pixels

pub fn scale_factor(&self) -> f64

Gets the intended scale factor of the sprite.

Returns

the sprite’s scale factor

pub fn source_paintable(&self) -> Option<Paintable>

Gets the source [gdk::Paintable][crate::gdk::Paintable] used to draw the sprite.

Note that VectorSprite also implements [gdk::Paintable][crate::gdk::Paintable]. In most cases, you should draw the sprite rather than the original paintable.

Returns

the source paintable

pub fn source_rect(&self) -> Option<Rectangle>

Gets the source rectangle of the sprite.

Returns

the sprite’s source rectangle, or None if the entire paintable is used

pub fn width(&self) -> i32

Gets the width at which the sprite should be drawn.

Returns

the sprite’s width in pixels