pub trait MarkerExt: IsA<Marker> + 'static {
Show 21 methods
// Provided methods
fn animate_in(&self) { ... }
fn animate_in_with_delay(&self, delay: u32) { ... }
fn animate_out(&self) { ... }
fn animate_out_with_delay(&self, delay: u32) { ... }
fn child(&self) -> Option<Widget> { ... }
fn is_draggable(&self) -> bool { ... }
fn hotspot(&self) -> (f64, f64) { ... }
fn is_selectable(&self) -> bool { ... }
fn is_selected(&self) -> bool { ... }
fn set_child(&self, child: Option<&impl IsA<Widget>>) { ... }
fn set_draggable(&self, value: bool) { ... }
fn set_hotspot(&self, x_hotspot: f64, y_hotspot: f64) { ... }
fn set_selectable(&self, value: bool) { ... }
fn x_hotspot(&self) -> f64 { ... }
fn set_x_hotspot(&self, x_hotspot: f64) { ... }
fn y_hotspot(&self) -> f64 { ... }
fn set_y_hotspot(&self, y_hotspot: f64) { ... }
fn connect_child_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_selectable_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_x_hotspot_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
fn connect_y_hotspot_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId { ... }
}Provided Methods
fn animate_in(&self)
fn animate_in_with_delay(&self, delay: u32)
fn animate_out(&self)
fn animate_out_with_delay(&self, delay: u32)
fn is_draggable(&self) -> bool
Sourcefn is_selectable(&self) -> bool
fn is_selectable(&self) -> bool
Sourcefn is_selected(&self) -> bool
fn is_selected(&self) -> bool
fn set_draggable(&self, value: bool)
Sourcefn set_hotspot(&self, x_hotspot: f64, y_hotspot: f64)
fn set_hotspot(&self, x_hotspot: f64, y_hotspot: f64)
Sourcefn set_selectable(&self, value: bool)
fn set_selectable(&self, value: bool)
Sourcefn x_hotspot(&self) -> f64
fn x_hotspot(&self) -> f64
The x hotspot of the marker, a negative value means that the actual
x hotspot is calculated with the halign property.
The x hotspot should not be more than the width of the widget.
Sourcefn set_x_hotspot(&self, x_hotspot: f64)
fn set_x_hotspot(&self, x_hotspot: f64)
The x hotspot of the marker, a negative value means that the actual
x hotspot is calculated with the halign property.
The x hotspot should not be more than the width of the widget.
Sourcefn y_hotspot(&self) -> f64
fn y_hotspot(&self) -> f64
The y hotspot of the marker, a negative value means that the actual
y hotspot is calculated with the valign property.
The y hotspot should not be more than the height of the widget.
Sourcefn set_y_hotspot(&self, y_hotspot: f64)
fn set_y_hotspot(&self, y_hotspot: f64)
The y hotspot of the marker, a negative value means that the actual
y hotspot is calculated with the valign property.
The y hotspot should not be more than the height of the widget.
fn connect_child_notify<F: Fn(&Self) + 'static>(&self, f: F) -> SignalHandlerId
fn connect_selectable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_x_hotspot_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
fn connect_y_hotspot_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".